@@ -4,18 +4,19 @@ from django.template.context import RequestContext
 from django.views.generic.base import View
 from render import process_response, correct_path, render_template
 
-__author__ = 'phpdude'
 
-def get_template_app_folder(module, separator='/'):
+def get_template_app_folder(module):
     return module.split('.')[-2].lower()
 
-class RenderViewMixin():
-    template_name = None
 
+class RenderViewMixin(object):
+    template_name = None
 
     def get_template_names(self):
         if self.template_name is None:
-            template_name = ".".join((get_template_app_folder(self.__module__, '.'), self.__class__.__name__)).lower()
+            template_name = ".".join((
+                get_template_app_folder(self.__module__),
+                self.__class__.__name__)).lower()
             return ["%s.html" % template_name.replace('.', '/')]
 
         return [self.template_name]
@@ -35,9 +36,11 @@ class RenderViewMixin():
             **response_kwargs
         )
 
+    # noinspection PyAttributeOutsideInit
     def dispatch(self, request, *args, **kwargs):
         if request.method.lower() in View.http_method_names:
-            handler = getattr(self, request.method.lower(), self.http_method_not_allowed)
+            handler = getattr(self, request.method.lower(),
+                              self.http_method_not_allowed)
         else:
             handler = self.http_method_not_allowed
         self.request = request
@@ -49,8 +52,9 @@ class RenderViewMixin():
             return response
 
         module_name = get_template_app_folder(self.__module__)
-        template_name = self.get_template_names()[0][:-5] #strip .html extension
-        template_name, context_processors, mimetype = process_response(response, template_name)
+        template_name = self.get_template_names()[0][:-5]  # strip .html
+        template_name, context_processors, mimetype = process_response(
+            response, template_name)
         if not template_name.__contains__('/'):
             template_name = correct_path(template_name, module_name)
 
@@ -58,11 +62,12 @@ class RenderViewMixin():
         context_processors['View'] = self.__class__.__name__.lower()
         context_processors['Layout'] = correct_path('base.html', module_name)
 
-        return self.render_to_response(context_processors, mimetype=mimetype, template=template_name)
+        return self.render_to_response(context_processors, mimetype=mimetype,
+                                       template=template_name)
 
 
 def renderer(prefix=""):
-    def renderer(func):
+    def renderer_func(func):
         @wraps(func)
         def wrapper(request, *args, **kwargs):
             module_name = get_template_app_folder(func.__module__)
@@ -71,7 +76,8 @@ def renderer(prefix=""):
             if isinstance(response, HttpResponse):
                 return response
 
-            template_name, context_processors, mimetype = process_response(response, func.__name__)
+            template_name, context_processors, mimetype = process_response(
+                response, func.__name__)
 
             if prefix:
                 if isinstance(template_name, (list, tuple)):
@@ -83,13 +89,15 @@ def renderer(prefix=""):
 
             context_processors['App'] = module_name
             context_processors['View'] = func.__name__
-            context_processors['Layout'] = correct_path('base.html', prefix or module_name)
+            context_processors['Layout'] = correct_path('base.html',
+                                                        prefix or module_name)
 
-            return render_template(template_name, context_processors, context_instance=RequestContext(request),
+            return render_template(template_name, context_processors,
+                                   context_instance=RequestContext(request),
                                    mimetype=mimetype)
 
         return wrapper
 
-    return renderer
+    return renderer_func
 
 render = renderer()
